AboveBelowAverage class

Represents the above or below conditional formatting rule. Applying this rule to a range helps you highlight the cells which contain values above or below the average of selected range.

Constructors

AboveBelowAverage()

Properties

averageType ↔ ExcelCFAverageType
Specifies whether the conditional formatting rule looks for cell values above or below the range average or standard deviation.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stdDevValue ↔ int
Specifies standard deviation number for AboveBelowAverage conditional formatting rule. Valid only if AverageType is set to AboveStdDev or BelowStdDev.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited