AutoFilter class abstract

AutoFilter class

Constructors

AutoFilter()

Properties

filterType ↔ ExcelFilterType
Specifies the type of filter
getter/setter pair
firstCondition ↔ AutoFilterCondition
Represents the first condition for the filter.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
logicalOperator ↔ ExcelLogicalOperator
Indicates whether to use AND, OR logical operation between first and second conditions. By default, it uses OR operation.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondCondition ↔ AutoFilterCondition
Represents the second condition for the filter.
getter/setter pair

Methods

addColorFilter(String color, ExcelColorFilterType colorFilterType) → void
Applies color filter with the specified font or back color.
addDateFilter(DateTime dateTime, DateTimeFilterType groupingType) → void
Applies date filter with the specified date.
addDynamicFilter(DynamicFilterType dynamicFilterType) → void
Applies date filter with the specified date period.
addTextFilter(Set<String> filterCollection) → void
Applies text filter with the specified string collection.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited