AutoFilterCondition class abstract

Represents AutoFilter conditions class

Constructors

AutoFilterCondition()

Properties

conditionOperator ↔ ExcelFilterCondition
Represents the operator used for the filter.
getter/setter pair
dataType ↔ ExcelFilterDataType
Represent filter data type
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
numberValue ↔ double
Represents the number value used for the filter.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textValue ↔ String
Represents the text value used for the filter.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited