Border class

Represent cell individual border.

Implementers

Constructors

Border()

Properties

color ↔ String
Gets/sets borderline color.
getter/setter pair
colorRgb ↔ Color
Gets/sets borderline color Rgb.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lineStyle ↔ LineStyle
Gets/sets border line style.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited