Borders class

Represents cell borders

Implementers

Constructors

Borders()

Properties

all ↔ Border
Represent the all borders.
getter/setter pair
bottom ↔ Border
Represent the bottom border.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
left ↔ Border
Represent the left border.
getter/setter pair
Represent the right border.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
top ↔ Border
Represent the top border.
getter/setter pair
workbook ↔ Workbook
Represent the workbook.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited