BordersCollection class

Represents cell borders

Implemented types

Constructors

BordersCollection(Workbook book)
Creates an new instances of borders.

Properties

all ↔ Border
Represent the all borders.
getter/setter pairoverride
bottom ↔ Border
Represent the bottom border.
getter/setter pairoverride
hashCode → int
The hash code for this object.
no setteroverride
left ↔ Border
Represent the left border.
getter/setter pairoverride
Represent the right border.
getter/setter pairoverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
top ↔ Border
Represents the top border.
getter/setter pairoverride
workbook ↔ Workbook
Represent the workbook.
getter/setter pairoverride

Methods

clear() → void
Crear all the borders.
clone() → BordersCollection
Clone method of BordersCollecton.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object toCompare) → bool
Compares two instances of the Cell borders.
override