ColorConditionValueWrapper class

This object wraps ConditionValue object to ensure correct parent object update.

Inheritance

Constructors

ColorConditionValueWrapper(ColorConditionValueImpl value, ColorScaleWrapper parent)
Initializes new instance of the wrapped.

Properties

formatColor ↔ String
The color assigned to the threshold of a color scale conditional format.
getter/setter pairoverride
formatColorRgb ↔ Color
The color assigned to the threshold of a color scale conditional format in Rgb.
getter/setter pairoverride
hashCode → int
The hash code for this object.
no setterinherited
operator ↔ ConditionalFormatOperator
Returns or sets one of the constants of the ConditionalFormatOperator enumeration, which specifes if the threshold is "greater than" or "greater than or equal to" the threshold value.
getter/setter pairoverride
rgbValue → int
Gets the rgbValue of the color
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ ConditionValueType
Returns one of the constants of the XlConditionValueTypes enumeration, which specifies how the threshold values for a data bar, color scale, or icon set conditional format are determined. Read-only.
getter/setter pairoverride
value ↔ String
Returns or sets the shortest bar or longest bar threshold value for a data bar conditional format.
getter/setter pairoverride
wrapped ↔ ColorConditionValueImpl
Wrapped item.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited