ConditionValueImpl class

Represents implementation of single condition value for iconset, databar, colorscale conditions.

Inheritance

Constructors

ConditionValueImpl(ConditionValueType type, String value)
Initializes new instance of the class.

Properties

hashCode → int
The hash code for this object.
no setterinherited
operator ↔ ConditionalFormatOperator
Sets the operator for the threshold values in the conditional format.
getter/setter pairoverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ ConditionValueType
Returns or sets one of the constants of the ConditionValueType enumeration which specifies how the threshold values for a data bar, color scale, or icon set conditional format are determined.
getter/setter pairoverride
value ↔ String
Returns or sets threshold values for the conditional format.
getter/setter pairoverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited