ConditionalFormat class

Represents a conditional format.

Constructors

ConditionalFormat()

Properties

aboveBelowAverage ↔ AboveBelowAverage?
Gets AboveBelowAverage conditional formatting rule. Read-only.
getter/setter pair
backColor ↔ String
Gets or sets the background color from predefined colors.
getter/setter pair
backColorRgb ↔ Color
Gets or sets the background color from Rgb.
getter/setter pair
bottomBorderColor ↔ String
Gets or sets the bottom border color from predefined colors.
getter/setter pair
bottomBorderColorRgb ↔ Color
Gets or sets the bottom border color from Rgb .
getter/setter pair
bottomBorderStyle ↔ LineStyle
Gets or sets the bottom border line style.
getter/setter pair
colorScale ↔ ColorScale?
Gets color scale conditional formatting rule. Read-only.
getter/setter pair
dataBar ↔ DataBar?
Gets data bar conditional formatting rule.
getter/setter pair
firstFormula ↔ String
Gets or sets the value or expression associated with the conditional format.
getter/setter pair
firstFormulaR1C1 ↔ String
Gets or sets the value or expression associated with the conditional format in R1C1 notation.
getter/setter pair
fontColor ↔ String
Gets or sets the font color from predefined colors.
getter/setter pair
fontColorRgb ↔ Color
Gets or sets the background color from Rgb.
getter/setter pair
formatType ↔ ExcelCFType
Gets or sets the type of the conditional format.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
iconSet ↔ IconSet?
Gets icon set conditional formatting rule.
getter/setter pair
isBold ↔ bool
Gets or sets a boolean value indicating whether the font is bold.
getter/setter pair
isItalic ↔ bool
Gets or sets a boolean value indicating whether the font is italic.
getter/setter pair
leftBorderColor ↔ String
Gets or sets the left border color from predefined colors.
getter/setter pair
leftBorderColorRgb ↔ Color
Gets or sets the left border color from Rgb .
getter/setter pair
leftBorderStyle ↔ LineStyle
Gets or sets the left border line style.
getter/setter pair
numberFormat ↔ String?
Gets or sets number format of the conditional format rule.
getter/setter pair
operator ↔ ExcelComparisonOperator
Gets or sets the comparison operator for the conditional format.
getter/setter pair
rightBorderColor ↔ String
Gets or sets the right border color from predefined colors.
getter/setter pair
rightBorderColorRgb ↔ Color
Gets or sets the right border color from Rgb .
getter/setter pair
rightBorderStyle ↔ LineStyle
Gets or sets the right border line style.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondFormula ↔ String
Gets the value or expression associated with the second part of a conditional format.
getter/setter pair
secondFormulaR1C1 ↔ String
Gets or sets the value or expression associated with the conditional format in R1C1 notation.
getter/setter pair
stopIfTrue ↔ bool
Gets or sets a boolean value that determines if additional formatting rules on the cell should be evaluated if the current rule evaluates to True.
getter/setter pair
text ↔ String?
Gets or sets the text value used for specific text conditional formatting rule. The default value is null.
getter/setter pair
timePeriodType ↔ CFTimePeriods
Gets or sets one of the constants of see cref="CFTimePeriods" enumeration which represents the type of the time period.
getter/setter pair
topBorderColor ↔ String
Gets or sets the top border color from predefined colors.
getter/setter pair
topBorderColorRgb ↔ Color
Gets or sets the top border color from Rgb .
getter/setter pair
topBorderStyle ↔ LineStyle
Gets or sets the top border line style.
getter/setter pair
topBottom ↔ TopBottom?
Gets TopBottom conditional formatting rule. Read-only.
getter/setter pair
underline ↔ bool
Gets or sets the underline type for the conditional format.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited