DataBar class abstract

Represents a data bar conditional formatting rule. Applying a data bar to a range helps you see the value of a cell relative to other cells.

Constructors

DataBar()

Properties

barAxisColor ↔ String
Gets or sets the axis color of the data bar.
getter/setter pair
barAxisColorRgb ↔ Color
Gets or sets the axis color of the data bar in Rgb.
getter/setter pair
barColor ↔ String
Gets or sets the color of the bars in a data bar conditional format.
getter/setter pair
barColorRgb ↔ Color
The color of the bars in a data bar conditional format in Rgb.
getter/setter pair
borderColor ↔ String
Gets or sets the border color of the data bar.
getter/setter pair
borderColorRgb ↔ Color
Gets or sets the border color of the data bar in Rgb.
getter/setter pair
dataBarAxisPosition ↔ DataBarAxisPosition
Gets or sets the axis position for the data bar.
getter/setter pair
dataBarDirection ↔ DataBarDirection
Gets or sets the direction of the data bar.
getter/setter pair
hasBorder ↔ bool
Gets a Boolean value indicating whether the data bar has a border.
getter/setter pair
hasGradientFill ↔ bool
Gets or sets a Boolean value indicating whether the data bar has a gradient fill.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maxPoint ↔ ConditionValue
Gets a ConditionValue object which specifies how the longest bar is evaluated for a data bar conditional format.
getter/setter pair
minPoint ↔ ConditionValue
Gets a ConditionValue object which specifies how the shortest bar is evaluated for a data bar conditional format.
getter/setter pair
negativeBorderColor ↔ String
Gets or sets the negative border color of the data bar.
getter/setter pair
negativeBorderColorRgb ↔ Color
Gets or sets the negative border color of the data bar in Rgb.
getter/setter pair
negativeFillColor ↔ String
Gets or sets the negative fill color of the data bar. This element MUST exist if and only if negativeBarColorSameAsPositive equals "false".
getter/setter pair
negativeFillColorRgb ↔ Color
Gets or sets the negative fill color of the data bar in Rgb. This element MUST exist if and only if negativeBarColorSameAsPositive equals "false".
getter/setter pair
percentMax ↔ int
Gets or sets a value that specifies the length of the longest data bar as a percentage of cell width.
getter/setter pair
percentMin ↔ int
Gets or sets a value that specifies the length of the shortest data bar as a percentage of cell width.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showValue ↔ bool
Gets or sets a Boolean value that specifies if the value in the cell should be displayed or not. Default value is true.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited