DataValidation class

Represents data validation for a worksheet range.

Constructors

DataValidation()

Properties

allowType ↔ ExcelDataValidationType
Gets or sets the type of allowType.
getter/setter pair
comparisonOperator ↔ ExcelDataValidationComparisonOperator
Gets or sets the comparisonOperator.
getter/setter pair
dataRange ↔ Range
Gets or sets the dataRange, which acts as a list type.
getter/setter pair
errorBoxText ↔ String
Gets or sets the errorBoxText.
getter/setter pair
errorBoxTitle ↔ String
Gets or sets the errorBoxTitle.
getter/setter pair
errorStyle ↔ ExcelDataValidationErrorStyle
Gets or sets the errorStyle.
getter/setter pair
firstDateTime ↔ DateTime
Gets or sets the firstDateTime.
getter/setter pair
firstFormula ↔ String
Gets or sets the firstFormula.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isEmptyCellAllowed ↔ bool
Gets or sets the isEmptyCellAllowed.
getter/setter pair
isListInFormula ↔ bool
Gets or sets the isListInFormula which is used both internally and externally.
getter/setter pair
isPromptBoxPositionFixed ↔ bool
Gets or sets the isPromptBoxPositionFixed.
getter/setter pair
isSuppressDropDownArrow ↔ bool
Gets or sets the isSuppressDropDownArrow.
getter/setter pair
listOfValues ↔ List<String>
Gets or sets the listOfValues for DataValidation
getter/setter pair
promptBoxHPosition ↔ int
Gets or sets the promptBoxHPosition.
getter/setter pair
promptBoxText ↔ String
Gets or sets the promptBoxText.
getter/setter pair
promptBoxTitle ↔ String
Gets or sets the promptBoxTitle.
getter/setter pair
promptBoxVPosition ↔ int
Gets or sets the promptBoxVPosition.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondDateTime ↔ DateTime
Gets or sets the secondDateTime.
getter/setter pair
secondFormula ↔ String
Gets or sets the secondFormula
getter/setter pair
showErrorBox ↔ bool
Gets or sets the showErrorBox.
getter/setter pair
showPromptBox ↔ bool
Gets or sets the showPromptBox.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited