DateTimeFormatInfo class

Represents the Date Time Format Info class.

Constructors

DateTimeFormatInfo(String locale)
Create an instances of Date Time Format Info class.

Properties

dateSeparator ↔ String
Represents date separator.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maxSupportedDateTime → DateTime
Maximum supported date time.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shortDatePattern ↔ String
The custom format string for a short date value.
getter/setter pair
shortTimePattern ↔ String
The custom format string for a short time value.
getter/setter pair
timeSeparator ↔ String
Represents time separator.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited