ExcelCFType enum

Specifies whether the conditional format is based on a cell value or an expression.

Inheritance
Available extensions

Values

cellValue → const ExcelCFType

Represents the Cell Value option for conditional formatting.

formula → const ExcelCFType

Represents the Formula option for conditional formatting.

colorScale → const ExcelCFType

Represents the ColorScale option for conditional formatting.

dataBar → const ExcelCFType

Represents the DataBar option for conditional formatting.

iconSet → const ExcelCFType

Represents the IconSet option for conditional formatting.

blank → const ExcelCFType

Represents conditional formatting rule highlights cells that are completely blank.

noBlank → const ExcelCFType

Represents conditional formatting rule highlights cells that are not blank.

specificText → const ExcelCFType

Represents the Specific Text conditional formatting rule based on the text.

containsErrors → const ExcelCFType

Represents conditional formatting rule highlights cells that contains errors.

notContainsErrors → const ExcelCFType

Represents conditional formatting rule highlights cells that does not contains errors.

timePeriod → const ExcelCFType

Represents Time Period conditional formatting rule highlights cells that has date time.

duplicate → const ExcelCFType

Represents conditional formatting rule to highlight the cells with duplicate values.

unique → const ExcelCFType

Represents conditional formatting rule to highlight the cells with unique values.

topBottom → const ExcelCFType

Represents conditional formatting rule to highlight the top 10 or bottom 10 cells with the values.

aboveBelowAverage → const ExcelCFType

Represents conditional formatting rule to highlight the cells that contain values above or below the range average.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<ExcelCFType>
A constant List of the values in this enum, in order of their declaration.