ExcelTable class

Represents a Table in a Worksheet.

Constructors

ExcelTable()

Properties

altTextSummary ↔ String
Gets or sets the alternative text description.
getter/setter pair
altTextTitle ↔ String
Gets or sets the alternative text title.
getter/setter pair
builtInTableStyle ↔ ExcelTableBuiltInStyle
Gets or sets the built-in style for the table.
getter/setter pair
columns ↔ List<ExcelTableColumn>
Gets collection of columns in the table. Read-only.
getter/setter pair
dataRange ↔ Range
Gets or sets the dataRange, which acts as a list type.
getter/setter pair
displayName ↔ String
Gets or sets the display name for the table.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showBandedColumns ↔ bool
Gets or sets a Boolean value indicating whether column stripes are present.
getter/setter pair
showBandedRows ↔ bool
Gets or sets a Boolean value indicating whether row stripes are present.
getter/setter pair
showFirstColumn ↔ bool
Gets or sets a Boolean value indicating whether first column format is present.
getter/setter pair
showHeaderRow ↔ bool
Gets or sets a Boolean value indicating whether to hide/display the header row.
getter/setter pair
showLastColumn ↔ bool
Gets or sets a Boolean value indicating whether last column format is present.
getter/setter pair
showTotalRow ↔ bool
Gets or sets a Boolean value indicating whether the Total row is visible.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited