ExcelTableCollection class

Represents collections of tables in a worksheet.

Constructors

ExcelTableCollection(Worksheet worksheet)
Create a instances of tables collection.

Properties

count → int
Returns the count of table reference collection.
no setter
hashCode → int
The hash code for this object.
no setterinherited
innerList → List<ExcelTable>
Gets the inner list.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → void
create(String tableName, Range range) → ExcelTable
Creates a table with specified name and data range.Adds it to the List Objects collection.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(ExcelTable table) → bool
Removes a table from the worksheet.
removeAt(int index) → void
Removes a table from the worksheet at the specified index.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](dynamic index) → ExcelTable
table Cell Index.