ExcelTableColumn class

Represents a column in the table.

Constructors

ExcelTableColumn()

Properties

columnName ↔ String
Gets or sets the name of the column.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalFormula ↔ ExcelTableTotalFormula
Gets or sets the function used for total calculation.
getter/setter pair
totalRowLabel ↔ String
Gets or sets the label for the total row.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited