Font class

Represents cell font.

Constructors

Font()
Creates an new instances of Font.
Font.withNameSize(String name, double size)

Properties

bold ↔ bool
Gets/sets font bold.
getter/setter pair
color ↔ String
Gets/sets font color.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
italic ↔ bool
Gets/sets font italic.
getter/setter pair
name ↔ String
Gets/sets font name.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size ↔ double
Gets/sets font size.
getter/setter pair
underline ↔ bool
Gets/sets font underline.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited