FormatsCollection class

Constructors

FormatsCollection(Workbook workbook)
Initializes new instance and sets its application and parent objects.

Properties

count → int
Gets the number of elements contained in the collection. Read-only
no setter
hashCode → int
The hash code for this object.
no setterinherited
parent → Workbook
Represents the parent object.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → void
Removes all elements from the IDictionary.
contains(int key) → bool
Determines whether the IDictionary contains an element with the specified key.
createFormat(String? formatString) → int
Method that creates format object based on the format string and registers it in the workbook.
findOrCreateFormat(String? formatString) → int
Searches for format with specified format string and creates one if a match is not found.
getUsedFormats() → List<Format>
Gets all used formats.
insertDefaultFormats() → void
Inserts all default formats into list.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](dynamic index) → Format
Indexer of the class

Constants

exponent → const String
Represents the Exponenet Symbol.