Hyperlink class

Represent the Hyperlink object.

Constructors

Hyperlink(Worksheet sheet)
Creates an instance of Hyperlink.
Hyperlink.add(String address, [String? screenTip, String? textToDisplay, HyperlinkType? type])
Creates an instance of Hyperlink with parameters.

Properties

address ↔ String
Represents hyperlink target String.
getter/setter pair
attachedType ↔ ExcelHyperlinkAttachedType
Represent the hyperlink applied object name.
getter/setter pair
column ↔ int
Column Index
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isHyperlinkStyle ↔ BuiltInStyles?
Represents the Hyperlink built in style.
getter/setter pair
reference → String
Represents the cell reference name.
no setter
row ↔ int
Row index
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screenTip ↔ String?
Represents tooltip String.
getter/setter pair
textToDisplay ↔ String?
Returns or sets the text to be displayed for the specified hyperlink. The default value is the address of the hyperlink.
getter/setter pair
type ↔ HyperlinkType
Returns or sets the hyperlink type.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited