IconConditionValue class

Represents a condition value for IconSet conditions.

Inheritance
Implementers

Constructors

IconConditionValue()

Properties

hashCode → int
The hash code for this object.
no setterinherited
iconSet ↔ ExcelIconSetType
Returns or sets one of the constants of the IconConditionValueType enumeration. It specifies how the threshold values for icon set conditional format are determined. /// Returns or sets index of the iconset type's individual icon index.
getter/setter pair
index ↔ int
Returns or sets index of the iconset type's individual icon index. /// Returns or sets index of the iconset type's individual icon index.
getter/setter pair
operator ↔ ConditionalFormatOperator
Gets or sets the operator for the threshold values in the conditional format.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ ConditionValueType
Gets or sets a condition value which specifies how the threshold values for a DataBar, ColorScale and IconSet conditional format are determined. By default for IconSets ConditionValue.type property is set to ConditionValueType.percent. Here for example, we set ConditionValueType.percentile to ConditionValue.type property.
getter/setter pairinherited
value ↔ String
Gets or sets the shortest bar or longest bar threshold value for a data
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited