IconSet class abstract

Represents a set of icons that are used in an icon set conditional formatting rule.

Constructors

IconSet()

Properties

hashCode → int
The hash code for this object.
no setterinherited
iconCriteria ↔ List<ConditionValue>
Gets ConditionValue collection which represents the set of criteria for icon set conditional formatting rule.
getter/setter pair
iconSet ↔ ExcelIconSetType
Gets or sets the type of the icon set conditional formatting.
getter/setter pair
percentileValues ↔ bool
Gets or sets a Boolean value indicating if the thresholds for an icon set conditional format are determined using percentiles. Default value is false.
getter/setter pair
reverseOrder ↔ bool
Gets or sets a Boolean value indicating if the order of icons are reversed for an icon set. Default value is false.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showIconOnly ↔ bool
Gets or sets a Boolean value indicating if only the icon is displayedfor an icon set conditional format. Default value is false.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited