Name class abstract

Represents collections of pagesetup in a worksheet.

Constructors

Name()

Properties

description ↔ String
Represents the comments for the named range.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
index ↔ int
Returns the named range index from the named range collection.
getter/setter pair
isLocal ↔ bool
Indicates whether the named range is local.
getter/setter pair
isVisible ↔ bool
Indicates whether the named range is visible.
getter/setter pair
name ↔ String
Returns or sets the name for the named range.
getter/setter pair
refersToRange ↔ Range
Represents the referred worksheet range for the named range.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope ↔ String
Represents the scope of the named range whether it is workbook/worksheet.
getter/setter pair
value ↔ String
Represents the value of the worksheet.
getter/setter pair
worksheet ↔ Worksheet
Returns parent worksheet of the named range.
getter/setter pair

Methods

delete() → void
Deletes a named range from the workbook/worksheet.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited