Picture class

Represent the Excel image.

Constructors

Picture(List<int> imageData)
Create an instances of Picture class.

Properties

column ↔ int
Gets/Sets the image column.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ int
Gets/Sets the image height.
getter/setter pair
horizontalFlip ↔ bool
Gets/Sets the image horizontal flip.
getter/setter pair
Gets/Sets the image hyperlink.
getter/setter pair
imageData → List<int>?
Gets/Sets the image String.
no setter
getter/setter pair
lastColOffset ↔ double
Gets/Sets the image last column offset.
getter/setter pair
lastColumn ↔ int
Gets/Sets the image last column.
getter/setter pair
lastRow ↔ int
Gets/Sets the image last row.
getter/setter pair
lastRowOffset ↔ double
Gets/Sets the image last row offset.
getter/setter pair
rotation ↔ int
Gets/Sets the image rotation.
getter/setter pair
row ↔ int
Gets/Sets the image row.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
verticalFlip ↔ bool
Gets/Sets the image vertical flip.
getter/setter pair
width ↔ int
Gets/Sets the image width.
getter/setter pair

Methods

clear() → void
clear the image data.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

isJpeg(List<int>? imageData) → bool
Check whether the picture is jpeg.
isPng(List<int>? imageData) → bool
Check whether the picture is png.