Row class

Represents the worksheet row.

Constructors

Row(Worksheet sheet)
Create an instance of Row.

Properties

hashCode → int
The hash code for this object.
no setterinherited
height ↔ double
Represents the row height.
getter/setter pair
index ↔ int
Represents the row index.
getter/setter pair
isHidden ↔ bool
Represents the indicate wheather row hide or not.
getter/setter pair
ranges → RangeCollection
Gets/Sets a images collections in the worksheet.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
worksheet → Worksheet
Represents parent worksheet.
no setter

Methods

clear() → void
clear the row.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited