RowCollection class

Represents the worksheet rows.

Constructors

RowCollection(Worksheet worksheet)
Create a instance of rows collection.

Properties

count → int
Returns the count of pivot reference collection.
no setter
hashCode → int
The hash code for this object.
no setterinherited
innerList → List<Row?>
Represents the inner list.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
worksheet → Worksheet
Represents parent worksheet.
no setter

Methods

add() → Row
Add row to the row collection.
clear() → void
Clear the row.
getRow(int rowIndex) → Row?
Get a row from rows collection based on row index.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](int index) → Row?
Indexer get of the class
operator []=(int index, Row? value) → void
Indexer set of the class