Style class

Represents the Style class.

Implementers

Constructors

Style()

Properties

backColor ↔ String
Gets/sets back color.
getter/setter pair
backColorRgb ↔ Color
Gets/sets back color Rgb.
getter/setter pair
bold ↔ bool
Gets/sets font bold.
getter/setter pair
borders ↔ Borders
Gets/sets borders.
getter/setter pair
fontColor ↔ String
Gets/sets font color.
getter/setter pair
fontColorRgb ↔ Color
Gets/sets font color Rgb.
getter/setter pair
fontName ↔ String
Gets/sets font name.
getter/setter pair
fontSize ↔ double
Gets/sets font size.
getter/setter pair
hAlign ↔ HAlignType
Gets/sets horizontal alignment.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
indent ↔ int
Gets/sets cell indent.
getter/setter pair
index ↔ int
Represents cell style index.
getter/setter pair
italic ↔ bool
Gets/sets font italic.
getter/setter pair
locked ↔ bool
Gets/Sets cell Lock
getter/setter pair
name ↔ String
Represents cell style name.
getter/setter pair
numberFormat ↔ String?
Gets/sets cell numberFormat.
getter/setter pair
numberFormatIndex ↔ int
Gets/sets cell numberFormat index.
getter/setter pair
rotation ↔ int
Gets/sets cell rotations.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
underline ↔ bool
Gets/sets font underline.
getter/setter pair
vAlign ↔ VAlignType
Gets/sets vertical alignment.
getter/setter pair
wrapText ↔ bool
Gets/sets cell wraptext.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited