StylesCollection class

Represents styles collection.

Constructors

StylesCollection(Workbook workbook)
Create an instance of Worksheets

Properties

count → int
Returns the count of pivot reference collection.
no setter
hashCode → int
The hash code for this object.
no setterinherited
innerList → List<Style>
Collection of worksheet
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
workbook → Workbook
Represents parent workbook
no setter

Methods

add(String styleName) → Style
Add styles to the collection
addStyle(CellStyle style) → void
Add styles to the collection
clear() → void
clear the cell style.
contains(String? styleName) → bool
Method returns True if collection contains style with specified by user name.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](dynamic index) → Style?
Indexer of the class