TopBottom class

Represents the top or bottom conditional formatting rule. Applying this rule to a range helps you highlight the top or bottom “n” cells from the selected range.

Constructors

TopBottom()

Properties

hashCode → int
The hash code for this object.
no setterinherited
percent ↔ bool
Specifies whether the rank is determined by a percentage value.
getter/setter pair
rank ↔ int
Specifies the maximum number or percentage of cells to be highlighted for this conditional formatting rule.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ ExcelCFTopBottomType
Specifies whether the ranking is evaluated from the top or bottom.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited